@@ -39,20 +39,14 @@ import io
 import importlib
 import itertools
 
-try:
+with contextlib.suppress(ImportError):
     import win32security
-except ImportError:
-    pass
 
-try:
+with contextlib.suppress(ImportError):
     import pwd
-except ImportError:
-    pass
 
-try:
+with contextlib.suppress(ImportError):
     import grp
-except ImportError:
-    pass
 
 from . import matchers
 from .py37compat import best_realpath, lru_cache
@@ -162,6 +156,8 @@ class Path(str):
     def __init__(self, other=''):
         if other is None:
             raise TypeError("Invalid initial value for path: None")
+        with contextlib.suppress(AttributeError):
+            self._validate()
 
     @classmethod
     @lru_cache
@@ -554,29 +550,13 @@ class Path(str):
         `errors` may also be an arbitrary callable taking a msg parameter.
         """
 
-        class Handlers:
-            def strict(msg):
-                raise
-
-            def warn(msg):
-                warnings.warn(msg, TreeWalkWarning)
-
-            def ignore(msg):
-                pass
-
-        if not callable(errors) and errors not in vars(Handlers):
-            raise ValueError("invalid errors parameter")
-        errors = vars(Handlers).get(errors, errors)
-
+        errors = Handlers._resolve(errors)
         match = matchers.load(match)
 
         try:
             childList = self.listdir()
-        except Exception:
-            exc = sys.exc_info()[1]
-            tmpl = "Unable to list directory '%(self)s': %(exc)s"
-            msg = tmpl % locals()
-            errors(msg)
+        except Exception as exc:
+            errors(f"Unable to list directory '{self}': {exc}")
             return
 
         for child in childList:
@@ -586,12 +566,8 @@ class Path(str):
             traverse = traverse or child.isdir
             try:
                 do_traverse = traverse()
-            except Exception:
-                exc = sys.exc_info()[1]
-                tmpl = "Unable to access '%(child)s': %(exc)s"
-                msg = tmpl % locals()
-                errors(msg)
-                isdir = False
+            except Exception as exc:
+                errors(f"Unable to access '{child}': {exc}")
 
             if do_traverse:
                 for item in child.walk(errors=errors, match=match):
@@ -1314,7 +1290,7 @@ class Path(str):
         symlinks=False,
         *,
         copy_function=shutil.copy2,
-        ignore=lambda dir, contents: []
+        ignore=lambda dir, contents: [],
     ):
         """
         Copy entire contents of self to dst, overwriting existing
@@ -1416,11 +1392,8 @@ class Path(str):
         # move existing file to backup, create new file with same permissions
         # borrowed extensively from the fileinput module
         backup_fn = self + (backup_extension or os.extsep + 'bak')
-        try:
-            os.unlink(backup_fn)
-        except os.error:
-            pass
-        os.rename(self, backup_fn)
+        backup_fn.remove_p()
+        self.rename(backup_fn)
         readable = io.open(
             backup_fn,
             mode,
@@ -1432,8 +1405,7 @@ class Path(str):
         try:
             perm = os.fstat(readable.fileno()).st_mode
         except OSError:
-            writable = open(
-                self,
+            writable = self.open(
                 'w' + mode.replace('r', ''),
                 buffering=buffering,
                 encoding=encoding,
@@ -1453,31 +1425,22 @@ class Path(str):
                 errors=errors,
                 newline=newline,
             )
-            try:
-                if hasattr(os, 'chmod'):
-                    os.chmod(self, perm)
-            except OSError:
-                pass
+            with contextlib.suppress(OSError, AttributeError):
+                self.chmod(perm)
         try:
             yield readable, writable
         except Exception:
             # move backup back
             readable.close()
             writable.close()
-            try:
-                os.unlink(self)
-            except os.error:
-                pass
-            os.rename(backup_fn, self)
+            self.remove_p()
+            backup_fn.rename(self)
             raise
         else:
             readable.close()
             writable.close()
         finally:
-            try:
-                os.unlink(backup_fn)
-            except os.error:
-                pass
+            backup_fn.remove_p()
 
     @ClassProperty
     @classmethod
@@ -1533,6 +1496,35 @@ def only_newer(copy_func):
     return wrapper
 
 
+class ExtantPath(Path):
+    """
+    >>> ExtantPath('.')
+    ExtantPath('.')
+    >>> ExtantPath('does-not-exist')
+    Traceback (most recent call last):
+    OSError: does-not-exist does not exist.
+    """
+
+    def _validate(self):
+        if not self.exists():
+            raise OSError(f"{self} does not exist.")
+
+
+class ExtantFile(Path):
+    """
+    >>> ExtantFile('.')
+    Traceback (most recent call last):
+    FileNotFoundError: . does not exist as a file.
+    >>> ExtantFile('does-not-exist')
+    Traceback (most recent call last):
+    FileNotFoundError: does-not-exist does not exist as a file.
+    """
+
+    def _validate(self):
+        if not self.isfile():
+            raise FileNotFoundError(f"{self} does not exist as a file.")
+
+
 class SpecialResolver:
     class ResolverScope:
         def __init__(self, paths, scope):
@@ -1709,3 +1701,20 @@ def _permission_mask(mode):
         '=': lambda mask, target: target & retain ^ mask,
     }
     return functools.partial(op_map[op], mask)
+
+
+class Handlers:
+    def strict(msg):
+        raise
+
+    def warn(msg):
+        warnings.warn(msg, TreeWalkWarning)
+
+    def ignore(msg):
+        pass
+
+    @classmethod
+    def _resolve(cls, param):
+        if not callable(param) and param not in vars(Handlers):
+            raise ValueError("invalid errors parameter")
+        return vars(cls).get(param, param)
